/*
$Id: rnt.h,v 1.3 2005/07/18 21:11:41 rasc Exp $

 DVBSNOOP

 a dvb sniffer  and mpeg2 stream analyzer tool
 http://dvbsnoop.sourceforge.net/

 (c) 2001-2004   Rainer.Scherg@gmx.de (rasc)



*/


#ifndef __RNT_H
#define __RNT_H 


void section_TVA_RNT (u_char *b, int len);


#endif

